@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 12242 2020-05-20 07:23:17Z Trista $
+# $Id: models.py 12418 2020-07-23 07:38:18Z Casey $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Trista $
-# $Date: 2020-05-20 16:23:17 +0900 (週三, 20 五月 2020) $
-# $Revision: 12242 $
+# $Author: Casey $
+# $Date: 2020-07-23 15:38:18 +0800 (Thu, 23 Jul 2020) $
+# $Revision: 12418 $
 
 from functools import wraps
 from django import forms
@@ -218,12 +218,12 @@ class CallToActionModel(CMSPlugin):
 
 
 class CallToActionStatistics(models.Model):
-    action = models.ForeignKey(CallToActionModel)
+    action = models.ForeignKey(CallToActionModel, on_delete=models.CASCADE)
     token = models.CharField(max_length=80)
     email = models.CharField(max_length=500)
     count = models.IntegerField(default=0)
     url = models.CharField(max_length=500, blank=True, null=True)
-    article = models.ForeignKey(Article, related_name='callToActionStatistics', null=True)
+    article = models.ForeignKey(Article, on_delete=models.CASCADE, related_name='callToActionStatistics', null=True)
     
    
 
