@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: append_template.py 11055 2018-05-14 09:46:32Z Lavender $
+# $Id: append_template.py 12415 2020-07-23 04:08:00Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-05-14 17:46:32 +0800 (週一, 14 五月 2018) $
-# $Revision: 11055 $
+# $Date: 2020-07-23 12:08:00 +0800 (Thu, 23 Jul 2020) $
+# $Revision: 12415 $
 
 import os
 import shutil
@@ -35,6 +35,30 @@ def findSettings(path):
             if f == 'settings.py':
                 return os.path.join(root, f)
     return None
+    
+def getCMSTemplates(templateDir):
+    templates = []
+    
+    path = templateDir
+    index = None
+    
+    for root, dirs, files in os.walk(path):
+        if path.endswith('/') or path.endswith('\\'):
+            relatedPath = root.replace(path, '')
+        else:
+            # 去掉第一個 / or \
+            relatedPath = root.replace(path, '')[1:]
+        for fileName in files:
+            templatePath = os.path.join(relatedPath, fileName)
+            if templatePath.lower() == 'index.html':
+                index = templatePath
+                continue
+            templates.append((templatePath, templatePath))
+              
+    if index:
+        return [(index, index),] + templates
+    else:
+        return templates
 
 class Command(BaseCommand):
 
@@ -55,19 +79,20 @@ class Command(BaseCommand):
             templateDir = settings.TEMPLATES[0]['DIRS'][0]
         except Exception as e:
             templateDir = 'templates'
-    
+        pageTemplateDir = os.path.join(templateDir, pageName) 
+        
         try:
             staticDir = settings.STATICFILES_DIRS[0]
         except Exception as e:
             staticDir = 'static'
             
-        hashDir = hashlib.md5(templatePath).hexdigest()
+        hashDir = hashlib.md5(templatePath.encode()).hexdigest()
 
         zip = zipfile.ZipFile(templatePath)
-        zip.extract('template.zip', '.')
-        zip.close()
+        # zip.extract('template.zip', '.')
+        # zip.close()
 
-        zip = zipfile.ZipFile('template.zip')
+        # zip = zipfile.ZipFile('template.zip')
         zip.extractall(hashDir)
         zip.close()
 
@@ -93,7 +118,11 @@ class Command(BaseCommand):
                 with open(htmlPath, 'w') as html:
                     html.write(content)
 
-
+        # get page template
+        pageTemplates = getCMSTemplates(pageTemplateDir)
+        pageTemplates = [
+            (os.path.join(pageName, t[0]), os.path.join(pageName, t[1])) for t in pageTemplates]
+        
         # modify settings
         settingsPath = findSettings('.')
         settingsDir = os.path.dirname(settingsPath)
@@ -103,44 +132,59 @@ class Command(BaseCommand):
             shutil.rmtree(os.path.join(staticDir, pageName))
             shutil.rmtree(os.path.join(templateDir, pageName))
             shutil.rmtree(hashDir)
-            os.remove('template.zip')
+            # os.remove('template.zip')
             return 
 
         shutil.copyfile(settingsPath, bak)
 
-        with open(settingsPath, 'r') as settingsFile:
+        with open(settingsPath, 'r', encoding="utf8") as settingsFile:
             content = settingsFile.read()
                
-        with open(settingsPath, 'w') as settingsFile: 
+        with open(settingsPath, 'w', encoding="utf8") as settingsFile: 
             content += \
 '''
 CMS_TEMPLATES = list(CMS_TEMPLATES)
-CMS_TEMPLATES += [
-    ('%s/index.html', '%s'),
-    ('%s/index_content.html', '%s_content'),
-]
-''' % (pageName, pageName, pageName, pageName)
-
+CMS_TEMPLATES += %s
+''' % str(pageTemplates)
+            
             settingsFile.write(content)
 
         # create page
         settings.CMS_TEMPLATES = list(settings.CMS_TEMPLATES)
-        settings.CMS_TEMPLATES += [
-            ('%s/index.html' % pageName, '%s' % pageName),
-            ('%s/index_content.html' % pageName, '%s_content' % pageName),
-        ]
-
-        page = create_page(
-            pageName, '%s/index_content.html' % pageName, 
-            LANGUAGE_CODE, published=True)
+        settings.CMS_TEMPLATES += pageTemplates
 
+        
+        # 主頁面
+        homepage = None
+        for t in pageTemplates:
+            if 'index_content.html' in t[0]:
+                logger.info("Create index page: %s" % t[0])
+                homepage = create_page(
+                    pageName, t[0], 
+                    LANGUAGE_CODE, published=True)
+                break
+                    
+        # 子頁面
+        if homepage:
+            for t in pageTemplates:
+                if not 'index_content.html' in t[0] and t[0].endswith("_content.html"):
+                    logger.info("Create page: %s" % t[0])
+                    name = t[0][:t[0].index("_content.html")]
+                    name = name.replace("%s/" % pageName, "").replace("%s\\" % pageName, "").replace("\\", "_").replace("/", "_")
+                    page1 = create_page(
+                        name, t[0], settings.LANGUAGE_CODE, 
+                        parent=homepage, published=True)
+        
         # pluginize
-        call_command(
-            'pluginize', template='index_content.html', templateDir=pageName)
+        for t in pageTemplates:
+            if '_content.html' in t[0]:
+                call_command(
+                    'pluginize', template=t[0].replace("%s/" % pageName, "").replace("%s\\" % pageName, ""), 
+                    templateDir=pageName)
 
-        page.template = '%s/index.html' % pageName
-        page.save()
+        # page.template = '%s/index.html' % pageName
+        # page.save()
 
         shutil.rmtree(hashDir)
-        os.remove('template.zip')
+        # os.remove('template.zip')
 
