@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_dumpdata.py 12280 2020-05-28 08:02:42Z Lavender $
+# $Id: cms_dumpdata.py 12415 2020-07-23 04:08:00Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-05-28 17:02:42 +0900 (週四, 28 五月 2020) $
-# $Revision: 12280 $
+# $Date: 2020-07-23 12:08:00 +0800 (Thu, 23 Jul 2020) $
+# $Revision: 12415 $
 
 import os
 import sys
@@ -27,6 +27,7 @@ else:
 
 from django.core.management.base import BaseCommand
 from django.core import serializers
+from django.conf import settings
 from django.db.models.query import QuerySet
 
 from Iuppiter.DjangoUtil import DJANGO_VERSION
@@ -84,13 +85,21 @@ class Command(BaseCommand):
             os.system(
                 "%s manage.py dumpdata cms.Treenode > treenodeData.json" %  
                 sys.executable)
-                
-            os.system(
-                ("%s manage.py dumpdata "
-                 "-e auth -e sites -e filer -e "
-                 "contenttypes -e cms.Treenode -e statistics"
-                 "> otherData.json") % 
-                 sys.executable)
+             
+            if "Zephyrus.statistics" in settings.INSTALLED_APPS:
+                os.system(
+                    ("%s manage.py dumpdata "
+                     "-e auth -e sites -e filer -e "
+                     "contenttypes -e cms.Treenode -e statistics"
+                     "> otherData.json") % 
+                     sys.executable)
+            else:
+                os.system(
+                    ("%s manage.py dumpdata "
+                     "-e auth -e sites -e filer -e "
+                     "contenttypes -e cms.Treenode"
+                     "> otherData.json") % 
+                     sys.executable)
         
             with open('authData.json') as f:
                 content = f.read()
