@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: pluginize.py 11840 2020-01-07 13:45:58Z Lavender $
+# $Id: pluginize.py 12415 2020-07-23 04:08:00Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-01-07 21:45:58 +0800 (週二, 07 一月 2020) $
-# $Revision: 11840 $
+# $Date: 2020-07-23 12:08:00 +0800 (Thu, 23 Jul 2020) $
+# $Revision: 12415 $
 
 import os
 import json
@@ -264,10 +264,13 @@ class Placeholder2(Placeholder):
                                 plugin_type='FilerImagePlugin',)
                     
                 else:
-                    textPlugin = Text.objects.create(
-                        placeholder=placeholder,
-                        language=Placeholder2.lang,
-                        body=content, plugin_type='TextPlugin')
+                    try:
+                        textPlugin = Text.objects.create(
+                            placeholder=placeholder,
+                            language=Placeholder2.lang,
+                            body=content, plugin_type='TextPlugin')
+                    except Exception as e:
+                        logger.error("Can't add content to text plugin: %s\n%s" % (str(e), content))
 
 class Command(BaseCommand):
     
